# -*- coding: utf-8 -*-
"""
Anonymize the first evaluation round of the German translation of the ASA questionnaire.

Date: 2023-05-19
Author: Nele Albers
"""

import pandas as pd
import pyreadstat  # for writing .sav-files


def anonymize(df_q, df_p, id_extension):
    """
    Anonymize the Qualtrics and Prolific data.
    Creates a new random ID called "rand_id".

    Parameters
    ----------
    df_q : dataframe
        Qualtrics data.
    df_p : dataframe
        Prolific data.
    id_extension : string
        Extension to add to new random IDs.

    Returns
    -------
    df_q : dataframe
        Anonymized Qualtrics data.
    df_p : dataframe
        Anonymized Prolific data.

    """

    # Only use qualtrics data of people who passed in prolific
    df_q = df_q[df_q["PROLIFIC_PID"].isin(df_p["Participant id"].to_list())]

    # Remove columns from qualtrics data that we cannot publish or do not need
    df_q = df_q.drop(["StartDate", "EndDate", "Status", "Progress", 
                      "Duration__in_seconds_", "RecordedDate", "ResponseId", 
                      "DistributionChannel", "UserLanguage", "Q_RecaptchaScore",
                      "PIV_E_G_Fluency_1", "PIV_E_G_Fluency_2", 
                      "PIV_E_G_Fluency_3", "PIV_E_G_Fluency_9",
                      "PIV_E_G_Fluency_5", "PIV_E_G_Fluency_10", 
                      "PIV_E_G_Fluency_8", "agentName", "SESSION_ID",
                      "STUDY_ID", "NoConsent_Check", "PROL_ID_C",
                      "TIME_VID_INTRO_First_Click", "TIME_VID_INTRO_Last_Click",
                      "TIME_VID_INTRO_Page_Submit", "TIME_VID_INTRO_Click_Count"], 
                     axis = 1)

    # Ceate random ID
    prolific_ids_sorted = sorted(df_q["PROLIFIC_PID"].to_list())
    df_q["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_q.iloc[i]["PROLIFIC_PID"]) + 1) + id_extension for i in range(len(df_q))]
    df_p["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_p.iloc[i]["Participant id"]) + 1) + id_extension for i in range(len(df_p))]

    # Drop original ID columns
    df_q = df_q.drop(["PROLIFIC_PID"], axis = 1)
    df_p = df_p.drop(["Participant id"], axis = 1)

    return df_q, df_p


if __name__ == "__main__":

    #### First the first half of the questionnaire

    # Load the data files we need
    df_q = pd.read_spss("Qualtrics_Exports/Round_1/Final_ASA_German_Round_1_First_Half_2023_05_19.sav")
    df_p_m = pd.read_excel("Prolific_Exports/Round_1/prolific_export_german_first_half_male_2023_05_19.xlsx")
    df_p_f = pd.read_excel("Prolific_Exports/Round_1/prolific_export_german_first_half_female_nonbinary_2023_05_18.xlsx")

    # Merge male and female prolific data
    df_p = pd.concat([df_p_m, df_p_f])

    # Anonymize
    df_q, df_p = anonymize(df_q, df_p, "_FH")

    # Save anonymized dataframes
    df_p.to_csv("Prolific_Exports/Round_1/prolific_export_german_first_half_anonym.csv",
                index=False)
    pyreadstat.write_sav(df_q, "Qualtrics_Exports/Round_1/Final_ASA_German_Round_1_First_Half_anonym.sav")


    #### Second half of the questionnaire

    # Read data files
    df_q = pd.read_spss("Qualtrics_Exports/Round_1/Final_ASA_German_Round_1_Second_Half_2023_05_19.sav")
    df_p_m = pd.read_excel("Prolific_Exports/Round_1/prolific_export_german_second_half_male_2023_05_19.xlsx")
    df_p_f = pd.read_excel("Prolific_Exports/Round_1/prolific_export_german_second_half_female_nonbinary_2023_05_19.xlsx")

    # Merge male and female prolific data
    df_p = pd.concat([df_p_m, df_p_f])

    # Anonymize
    df_q, df_p = anonymize(df_q, df_p, "_SH")

    # Save anonymized dataframes
    df_p.to_csv("Prolific_Exports/Round_1/prolific_export_german_second_half_anonym.csv",
                index=False)
    pyreadstat.write_sav(df_q, "Qualtrics_Exports/Round_1/Final_ASA_German_Round_1_Second_Half_anonym.sav")
