# -*- coding: utf-8 -*-
"""
Anonymize the second evaluation round of the German translation.

Date: 2023-05-31
Author: Nele Albers
"""

import pandas as pd
import pyreadstat  # for writing .sav-files


def anonymize(df_q, df_p):
    """
    Anonymize the Qualtrics and Prolific data.
    Creates a new random ID called "rand_id".

    Parameters
    ----------
    df_q : dataframe
        Qualtrics data.
    df_p : dataframe
        Prolific data.

    Returns
    -------
    df_q : dataframe
        Anonymized Qualtrics data.
    df_p : dataframe
        Anonymized Prolific data.

    """

    # Only use Qualtrics data of people who passed in prolific
    df_q = df_q[df_q["PROL_ID_C"].isin(df_p["Participant id"].to_list())]

    # Remove columns in Qualtrics data we cannot publish or do not need
    df_q = df_q.drop(["StartDate", "EndDate", "Status", "Progress", 
                      "Duration__in_seconds_", "RecordedDate", "ResponseId", 
                      "DistributionChannel", "UserLanguage", "Q_RecaptchaScore",
                      "PIV_E_G_Fluency_1", "PIV_E_G_Fluency_2", 
                      "PIV_E_G_Fluency_3", "PIV_E_G_Fluency_4",
                      "PIV_E_G_Fluency_5", "PIV_E_G_Fluency_6", 
                      "PIV_E_G_Fluency_7", "agentName", "SESSION_ID",
                      "STUDY_ID", "NoConsent_Check", "PROLIFIC_PID",
                      "TIME_VID_INTRO_First_Click", "TIME_VID_INTRO_Last_Click",
                      "TIME_VID_INTRO_Page_Submit", "TIME_VID_INTRO_Click_Count"], 
                     axis = 1)

    # Create random ID
    prolific_ids_sorted = sorted(df_q["PROL_ID_C"].to_list())
    df_q["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_q.iloc[i]["PROL_ID_C"]) + 1) + "_R2" for i in range(len(df_q))]
    df_p["rand_id"] = ["P" + str(prolific_ids_sorted.index(df_p.iloc[i]["Participant id"]) + 1) + "_R2" for i in range(len(df_p))]

    # Drop ID columns
    df_q = df_q.drop(["PROL_ID_C"], axis = 1)
    df_p = df_p.drop(["Participant id"], axis = 1)

    return df_q, df_p


if __name__ == "__main__":

    # Load data that we need
    df_q = pd.read_spss("Qualtrics_Exports/Round_2/Final_ASA_German_round2_2023_05_31.sav")
    df_p_m = pd.read_excel("Prolific_Exports/Round_2/prolific_export_german_round2_male_2023_05_31.xlsx")
    df_p_f = pd.read_excel("Prolific_Exports/Round_2/prolific_export_german_round2_female_nonbinary_2023_05_31.xlsx")

    # Merge male and female prolific data
    df_p = pd.concat([df_p_m, df_p_f])

    # Anonymize
    df_q, df_p = anonymize(df_q, df_p)

    # Save anonymized dataframes
    df_p.to_csv("Prolific_Exports/Round_2/prolific_export_german_anonym.csv",
                index=False)
    pyreadstat.write_sav(df_q, "Qualtrics_Exports/Round_2/Final_ASA_German_Round_2_anonym.sav")
